@@ -1,3 +1,5 @@
+//! Contains the [`World`] along with [`WorldError`]
+
 use crate::MapData;
 use crate::MapDataError;
 use async_std::fs::File;
@@ -46,10 +48,10 @@ impl World {
         let mut result = HashMap::new();
         let mut lines = reader.lines();
         while let Some(line) = lines.next().await {
-            if let Some((left, right)) = line?.split_once('=') {
+            if let Some((key, value)) = line?.split_once('=') {
                 result.insert(
-                    String::from(left.trim_end()),
-                    String::from(right.trim_start()),
+                    String::from(key.trim_end()),
+                    String::from(value.trim_start()),
                 );
             }
         }
@@ -82,27 +84,61 @@ impl World {
     /// use minetestworld::World;
     /// use async_std::task;
     ///
-    /// let meta = task::block_on(async {
+    /// let map_data = task::block_on(async {
     ///     World::new("TestWorld").get_map().await.unwrap()
     /// });
     /// ```
     pub async fn get_map(&self) -> Result<MapData, WorldError> {
         let backend = self.get_backend().await?;
-        if backend == "sqlite3" {
-            let World(path) = self;
-            Ok(MapData::from_sqlite_file(path.join("map.sqlite")).await?)
-        } else {
-            Err(WorldError::UnknownBackend(backend))
+        match backend.as_ref() {
+            #[cfg(feature = "sqlite")]
+            "sqlite3" => {
+                let World(path) = self;
+                Ok(MapData::from_sqlite_file(path.join("map.sqlite")).await?)
+            }
+            #[cfg(feature = "redis")]
+            "redis" => {
+                let meta = self.get_world_metadata().await?;
+                let host = meta.get("redis_address").ok_or_else(|| {
+                    WorldError::BogusBackendConfig(String::from(
+                        "The backend 'redis' requires a 'redis_address' in world.mt",
+                    ))
+                })?;
+                let host = url::Host::parse_opaque(host)?;
+                let port = meta.get("redis_port").map(|p| p.parse()).transpose()?;
+                let hash = meta.get("redis_hash").ok_or_else(|| {
+                    WorldError::BogusBackendConfig(String::from(
+                        "The backend 'redis' requires a 'redis_hash' in world.mt",
+                    ))
+                })?;
+                Ok(MapData::from_redis_connection_params(host, port, hash.clone()).await?)
+            }
+            _ => Err(WorldError::UnknownBackend(backend)),
         }
     }
 }
 
+/// Represents a failure to interact with the world
 #[derive(thiserror::Error, Debug)]
 pub enum WorldError {
     #[error("IO error: {0}")]
+    /// An IO error happened
     IOError(#[from] std::io::Error),
     #[error("Map data error: {0}")]
+    /// The map data backend returned an error
     MapDataError(#[from] MapDataError),
     #[error("Unknown backend '{0}'")]
+    /// The map data backend is not known or implemented
     UnknownBackend(String),
+    #[error("Bogus backend config: {0}")]
+    /// The map data baackend config contains an error
+    /// 
+    /// A description is included.
+    BogusBackendConfig(String),
+    #[error("Host parse error: {0}")]
+    /// Failure to parse an URL
+    ParseUrlError(#[from] url::ParseError),
+    #[error("Parse int error: {0}")]
+    /// Failure to parse an int from a string
+    ParseIntError(#[from] std::num::ParseIntError),
 }
